@@ -31,15 +31,15 @@ public slots:
     void addDownloadTransfer(const QString &contentPath, const QString &localPath);
     void addUploadTransfer(const QString &filePath, const QString &contentType, const QString &contentPath, bool isPublic);
 
+    void storeTransfers();
     void restoreStoredTransfers();
 
 private slots:
-    void storeTransfers();
     void storeAndDeleteTransfers();
 
     void startNextTransfers();
 
-    void onTransferStatusChanged(TransferStatus::Status status);
+    void onTransferStatusChanged(FileTransfer::Status status);
 
 signals:
     void countChanged(int count);
